@@ -77,7 +77,7 @@ class PseudocodefrLexer(RegexLexer):
             'core':[ # Statements
                     (r'\b(debut|début|fin|si|alors|sinon|fin[_ ]si|tant[ _]que|tantque|fin[ _]tantque|faire|répéter'
                     r'repeter|type|structure|fin[ _]structure|fonction|procédure|procedure|retourner|renvoyer|'
-                    r'pour|fin[ _]pour|à|déclarations?|jusque|spécialise|specialise|comporte|super|public|privé|protégé|'
+                    r'pour|variant|allant|de|fin[ _]pour|à|déclarations?|jusque|spécialise|specialise|comporte|super|public|privé|protégé|'
                     r'classe'
                     r')\s*\b', Keyword),
 
